==> v1.2021.4.tar.gz: plantuml/src/net/sourceforge/plantuml/project/lang/SentenceTaskStartsWithColor.java <==
/* ========================================================================
 * PlantUML : a free UML diagram generator
 * ========================================================================
 *
 * (C) Copyright 2009-2020, Arnaud Roques
 *
 * Project Info:  http://plantuml.com
 * 
 * If you like this project or if you find it useful, you can support us at:
 * 
 * http://plantuml.com/patreon (only 1$ per month!)
 * http://plantuml.com/paypal
 * 
 * This file is part of PlantUML.
 *
 * PlantUML is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * PlantUML distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA.
 *
 *
 * Original Author:  Arnaud Roques
 * 
 *
 */
package net.sourceforge.plantuml.project.lang;

import net.sourceforge.plantuml.command.CommandExecutionResult;
import net.sourceforge.plantuml.project.GanttConstraint;
import net.sourceforge.plantuml.project.GanttDiagram;
import net.sourceforge.plantuml.project.core.Task;
import net.sourceforge.plantuml.project.core.TaskAttribute;
import net.sourceforge.plantuml.project.core.TaskInstant;
import net.sourceforge.plantuml.ugraphic.color.HColor;

public class SentenceTaskStartsWithColor extends SentenceSimple {

	public SentenceTaskStartsWithColor() {
		super(new SubjectTask(), Verbs.starts2(),
				new PairOfSomething(new ComplementBeforeOrAfterOrAtTaskStartOrEnd(), new ComplementWithColorLink()));
	}

	@Override
	public CommandExecutionResult execute(GanttDiagram project, Object subject, Object complement) {
		final Task task = (Task) subject;
		final TaskInstant when;

		final Object[] pairs = (Object[]) complement;
		when = (TaskInstant) pairs[0];
		final CenterBorderColor complement22 = (CenterBorderColor) pairs[1];

		task.setStart(when.getInstantPrecise());
		if (when.isTask()) {
			final HColor color = complement22.getCenter();
			final GanttConstraint link = new GanttConstraint(when, new TaskInstant(task, TaskAttribute.START), color);
			link.applyStyle(complement22.getStyle());
			project.addContraint(link);
		}
		return CommandExecutionResult.ok();

	};
}

==> v1.2021.13.tar.gz: plantuml/src/net/sourceforge/plantuml/project/lang/SentenceTaskStartsWithColor.java <==
/* ========================================================================
 * PlantUML : a free UML diagram generator
 * ========================================================================
 *
 * (C) Copyright 2009-2020, Arnaud Roques
 *
 * Project Info:  http://plantuml.com
 * 
 * If you like this project or if you find it useful, you can support us at:
 * 
 * http://plantuml.com/patreon (only 1$ per month!)
 * http://plantuml.com/paypal
 * 
 * This file is part of PlantUML.
 *
 * PlantUML is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * PlantUML distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA.
 *
 *
 * Original Author:  Arnaud Roques
 * 
 *
 */
package net.sourceforge.plantuml.project.lang;

import net.sourceforge.plantuml.command.CommandExecutionResult;
import net.sourceforge.plantuml.project.GanttConstraint;
import net.sourceforge.plantuml.project.GanttDiagram;
import net.sourceforge.plantuml.project.core.Task;
import net.sourceforge.plantuml.project.core.TaskAttribute;
import net.sourceforge.plantuml.project.core.TaskInstant;
import net.sourceforge.plantuml.ugraphic.color.HColor;

public class SentenceTaskStartsWithColor extends SentenceSimple {

	public SentenceTaskStartsWithColor() {
		super(new SubjectTask(), Verbs.starts2(),
				new PairOfSomething(new ComplementBeforeOrAfterOrAtTaskStartOrEnd(), new ComplementWithColorLink()));
	}

	@Override
	public CommandExecutionResult execute(GanttDiagram diagram, Object subject, Object complement) {
		final Task task = (Task) subject;
		final TaskInstant when;

		final Object[] pairs = (Object[]) complement;
		when = (TaskInstant) pairs[0];
		final CenterBorderColor complement22 = (CenterBorderColor) pairs[1];

		task.setStart(when.getInstantPrecise());
		if (when.isTask()) {
			final HColor color = complement22.getCenter();
			final GanttConstraint link = new GanttConstraint(diagram.getIHtmlColorSet(),
					diagram.getCurrentStyleBuilder(), when, new TaskInstant(task, TaskAttribute.START), color);
			link.applyStyle(diagram.getSkinParam().getThemeStyle(), complement22.getStyle());
			diagram.addContraint(link);
		}
		return CommandExecutionResult.ok();

	};
}
